==> pcleaner-2.6.0-py3-none-any.whl: pcleaner/gui/rc_generated_files/rc_themes.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.6.2
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x02F\
(\
\xb5/\xfd`\x94\x0c\xe5\x11\x00\x06\x99L\x1f0s\x1e\
3k\x89!+\x9dP\xa5\xf5k\xea3\xc9\x99\xee\xaf\
\xc1iw\x09S\xe3\xc0\x81\x92\x8a\x86aD\x00C\x00\
A\x0043-\xc2y\xf4\xc89\xd7\xee\xdcg8\xdb\
\xfb\xd6K^c\xe9\xe6=5S\xd42ZsP\xae\
\x98\xfdl\x19\xcdE\x19\xc8\x18\xc5\xd9\xb6hf\x9b\xdd\
\x8b\xd02\xcev\xa9\xde\xc2P\xac\x1e\x06X\xa6>\x93\
A\xe0k]\x83%=989\xb6:\xa6\xe7:\xfa\
\xe3\x9b\xc0\xef\xb9\x8b\xf7\xbc\xa1\xe4\xda\xc9\x89e\xd4M\
P|\xa9?\xb4\x96\xa0O\x8b^\xf8B\xa2\xe8\xed\xce\
\xfbI7?S\x8b?[\x84\x0ak8\x14-\xb4\x8b\
\xbd9g\x85\x01\x16=f\x05\x15\xfdE{\xf4\x07\xbd\
_tIF\xb1%l\x87\xfe:z-9\x08\xd3l\
\xffz\xabs]\x83OS\xc7\xe8f\xf5\x95\x22\x05\x82\
W\xb1\x1bq\xb0\xa7\xd7\xf1E-\x9dk\x89s\xf6\xa6\
\x9edO\xce\xa9\xe6!qr\x01o\xd9\xfaV\xbb<\
*pR\xed\x8284\xec\x95e|%_\xd1\x0dF\
!-o4\xd5\x01\xf8\xd0?.\xcc\xbf~CI\xde\
\xbe\xe2s+[+\x9f\xaf\x94N\xcd\xd6\xbd\x93\x8e\xd1\
\x9f\xb7\xc0\xbd%\xb7H\xe8\xde\xee.\x82\x8e?n\xa0\
\x81\x99S\x8e\x18\x11\x83Be9@\xc8\x04eS\xa6\
\x0d\xb4x`7\xde*D\x0c\xf60D\x19\xf5\xd6\xe6\
\xd3\xa6\xed\x0f \x83\xdb#\x14[@0\xb8\x1e\x80\xec\
e\xc69\xd0\x17\xcce\xaf\x80I\x19$ 3\xdbz\
\x80X}&\xaa\x0f\xd4\xe0\xcd\xc3T\xb2\x11g\xad\xe0\
\xa9XTV\xc4\xc6\xe1\x16\xa8\x97{\xba\x06z\x06\x1a\
gM\xa2&\xb7\xe8\x03\x15\xd2\xe2$q\xce\xd5\xa0}\
\xd2\xea\xee\x07V\xa1\x00;\x8d\x92>\x80\xa0\x81\x98\xbd\
6\xda\x02}\xb9\x82\x88B6\x80\xc5\x19\x1f\x09\x06@\
\xd4\x9a\x9e6x\x12\x1c\x14\xd3\xb0\xd1! @\x80\xd4\
v\x0e,\xb7\xee\xc6\xc9\x1ae\x9d%\x17,\xe0\x8d\xef\
\xe27H\x03\x84\x80y\xd3\x01\x16\x08\x7f\xad\x837\xec\
g\x8e9\xc9o\xbf\xcd!\xba\x9c\x1a4Ts\xe0O\
\xd4\xeb\x8c_]\x17j\x1f\x156\x17\xb073>\xab\
/L\xa6\x0b0\x8b\xd9!\x0e\x80\x0e\xcc\x81\x96\x94\x1c\
\x8eE-M\x87\x94\xe7,\x14\xa1\xa3\xf7.\x0c\x823\
u\x22\xda\xbe*\
\x00\x00\x02\x22\
(\
\xb5/\xfd`~\x0c\xc5\x10\x00F\x97H\x1f0s\x1e\
3\xabd@\x9b\x80\xd1dm^l\xde\xa2S\xfd_\
\x83\xd3\xed-\x97\xf5\xc0\x81\x92\x8a\x86a?\x00?\x00\
>\x00\xf1E\xce\xb9~\xce}vs\xb5O_\xf2\x9a\
\xea\x9b\xf7\xcclye\xb4\xf6@y\xe2\xfa\xb92\x9a\
\x8bS c\xbf\xb9\xb6H\xe6\x9aY\x8c\xd0S\x94\xed\
r=\xc58\x9e\x87\x01\xce\xd6g2\x88k\xa95X\
\x02\xd7&\xee{\xec\x02\xc2\xd7\x12\xe5\xdaM\x12g\x96\
M\xf8\xb5\xd6\x1f\x9a \xb6\x14[ I\xea\xd8\xb5\x90\
\xc9\xb9\xa6\xaa\x8e\xa0\xfc\xec\xf5~\xa6\x84\xebj8\x96\
\x17\xda\xa5\xda\x9c\xb3\xc2\x00G\x8f\xa9gdE\xb8\x17\
TW0Z\xee_\xfe\x8b(\xf6\x03]\xcf\xf5\xb1\xa7\
\x1d\xcc\x1a^Uu\x8cN^?)\x93@\x00'\xb6\
\x91~\xf1E=IOR\xbf9\xab\xba\x9a\xbar\xcf\
5\x0f\x91^\xc3\xf8$\xa7N\x07%\x98\x9c\xfcu^\
\xf5i\xbb<*\x92\xb4\xda\x05qhXZ\xc5\xb2|\
\xad\xe4/\xdf`\x874\xce\xf5\x03\xe0C\xff\xb7 \x1f\
\xfb\x8d%\xa1~\xbf\xbe\xe2c\xaf:+\x0fv\x04\x9b\
zN\xea\x0av\xfc\xfc\xa4tf\xa6\xd6Nbd\xa0\
\x91\x11E\x8e\x10\x11\x83\x82J\xa1\x030\x88\x04\xc6\xc6\
N\x07B$\xec\xa8\xe1\x9c\xc4\xd8\xfa}8\xd5\xd1\x9d\
\xda\x0bT\xceU[\xb3\x87\x9ao\x89Y\x97>\xd9\x0c\
\xc9\xb02\xe0\x8d\x972'`\x06\xae\x02hz\xfd\xbf\
1e1U\x99\xa8Z\xe4\xaa\x90\x11o\x99\xed\xda\xb5\
|\x10\xd5.\xa2\xaa5\xb06D\xde\x0d\x8a-D\xe3\
\xc7.M\xc6\x8d\x94Y\x9eiS\xadx\x85\xb3\x9a)\
\x84\xd9\xcf\xe4\x896\x85\x09/fE\x22R\xd92\x10\
\xeeF\xcc\x9970\x06\x08\x08\x88-\xb0\xb9dop\
1\xcf\x1df$\xbd~\xbb\x0eX\xc9\x08\x0e\x0f\xf7)\
P\xd0\x80!D\x1cN\x99\xf0*5q\x19C6\x9e\
?\x5c\xa3\xa0\x1dT\x81\xc6o. \x88{\x9a\xe9W\
\xef\x02\xf6i\x91\xa6\x05\xe2\xf9L\xcf*\x94J\x86\x0f\
,\x8b\xd9\xa1\x87\xa4\x07\x10\x80HT~\xae\x22\x96\xaa\
E\xccw\x16!JBw]My\xc3\xee\x1a\xb45\
U\
"

qt_resource_name = b"\
\x00\x06\
\x07\xae\xc3\xc3\
\x00t\
\x00h\x00e\x00m\x00e\x00s\
\x00\x06\
\x06\x98\xbd\x05\
\x00b\
\x00r\x00e\x00e\x00z\x00e\
\x00\x0b\
\x00\xd0\xbf+\
\x00b\
\x00r\x00e\x00e\x00z\x00e\x00-\x00d\x00a\x00r\x00k\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00$\x00\x04\x00\x00\x00\x01\x00\x00\x02J\
\x00\x00\x01\x8a\x0b\xf6\xcb\xb0\
\x00\x00\x00\x12\x00\x04\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x8a\x0b\xf6\xcb\xb0\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()

==> pcleaner-2.6.2-py3-none-any.whl: pcleaner/gui/rc_generated_files/rc_themes.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.7.0
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x02F\
(\
\xb5/\xfd`\x94\x0c\xe5\x11\x00\x06\x99L\x1f0s\x1e\
3k\x89!+\x9dP\xa5\xf5k\xea3\xc9\x99\xee\xaf\
\xc1iw\x09S\xe3\xc0\x81\x92\x8a\x86aD\x00C\x00\
A\x0043-\xc2y\xf4\xc89\xd7\xee\xdcg8\xdb\
\xfb\xd6K^c\xe9\xe6=5S\xd42ZsP\xae\
\x98\xfdl\x19\xcdE\x19\xc8\x18\xc5\xd9\xb6hf\x9b\xdd\
\x8b\xd02\xcev\xa9\xde\xc2P\xac\x1e\x06X\xa6>\x93\
A\xe0k]\x83%=989\xb6:\xa6\xe7:\xfa\
\xe3\x9b\xc0\xef\xb9\x8b\xf7\xbc\xa1\xe4\xda\xc9\x89e\xd4M\
P|\xa9?\xb4\x96\xa0O\x8b^\xf8B\xa2\xe8\xed\xce\
\xfbI7?S\x8b?[\x84\x0ak8\x14-\xb4\x8b\
\xbd9g\x85\x01\x16=f\x05\x15\xfdE{\xf4\x07\xbd\
_tIF\xb1%l\x87\xfe:z-9\x08\xd3l\
\xffz\xabs]\x83OS\xc7\xe8f\xf5\x95\x22\x05\x82\
W\xb1\x1bq\xb0\xa7\xd7\xf1E-\x9dk\x89s\xf6\xa6\
\x9edO\xce\xa9\xe6!qr\x01o\xd9\xfaV\xbb<\
*pR\xed\x8284\xec\x95e|%_\xd1\x0dF\
!-o4\xd5\x01\xf8\xd0?.\xcc\xbf~CI\xde\
\xbe\xe2s+[+\x9f\xaf\x94N\xcd\xd6\xbd\x93\x8e\xd1\
\x9f\xb7\xc0\xbd%\xb7H\xe8\xde\xee.\x82\x8e?n\xa0\
\x81\x99S\x8e\x18\x11\x83Be9@\xc8\x04eS\xa6\
\x0d\xb4x`7\xde*D\x0c\xf60D\x19\xf5\xd6\xe6\
\xd3\xa6\xed\x0f \x83\xdb#\x14[@0\xb8\x1e\x80\xec\
e\xc69\xd0\x17\xcce\xaf\x80I\x19$ 3\xdbz\
\x80X}&\xaa\x0f\xd4\xe0\xcd\xc3T\xb2\x11g\xad\xe0\
\xa9XTV\xc4\xc6\xe1\x16\xa8\x97{\xba\x06z\x06\x1a\
gM\xa2&\xb7\xe8\x03\x15\xd2\xe2$q\xce\xd5\xa0}\
\xd2\xea\xee\x07V\xa1\x00;\x8d\x92>\x80\xa0\x81\x98\xbd\
6\xda\x02}\xb9\x82\x88B6\x80\xc5\x19\x1f\x09\x06@\
\xd4\x9a\x9e6x\x12\x1c\x14\xd3\xb0\xd1! @\x80\xd4\
v\x0e,\xb7\xee\xc6\xc9\x1ae\x9d%\x17,\xe0\x8d\xef\
\xe27H\x03\x84\x80y\xd3\x01\x16\x08\x7f\xad\x837\xec\
g\x8e9\xc9o\xbf\xcd!\xba\x9c\x1a4Ts\xe0O\
\xd4\xeb\x8c_]\x17j\x1f\x156\x17\xb073>\xab\
/L\xa6\x0b0\x8b\xd9!\x0e\x80\x0e\xcc\x81\x96\x94\x1c\
\x8eE-M\x87\x94\xe7,\x14\xa1\xa3\xf7.\x0c\x823\
u\x22\xda\xbe*\
\x00\x00\x02\x22\
(\
\xb5/\xfd`~\x0c\xc5\x10\x00F\x97H\x1f0s\x1e\
3\xabd@\x9b\x80\xd1dm^l\xde\xa2S\xfd_\
\x83\xd3\xed-\x97\xf5\xc0\x81\x92\x8a\x86a?\x00?\x00\
>\x00\xf1E\xce\xb9~\xce}vs\xb5O_\xf2\x9a\
\xea\x9b\xf7\xcclye\xb4\xf6@y\xe2\xfa\xb92\x9a\
\x8bS c\xbf\xb9\xb6H\xe6\x9aY\x8c\xd0S\x94\xed\
r=\xc58\x9e\x87\x01\xce\xd6g2\x88k\xa95X\
\x02\xd7&\xee{\xec\x02\xc2\xd7\x12\xe5\xdaM\x12g\x96\
M\xf8\xb5\xd6\x1f\x9a \xb6\x14[ I\xea\xd8\xb5\x90\
\xc9\xb9\xa6\xaa\x8e\xa0\xfc\xec\xf5~\xa6\x84\xebj8\x96\
\x17\xda\xa5\xda\x9c\xb3\xc2\x00G\x8f\xa9gdE\xb8\x17\
TW0Z\xee_\xfe\x8b(\xf6\x03]\xcf\xf5\xb1\xa7\
\x1d\xcc\x1a^Uu\x8cN^?)\x93@\x00'\xb6\
\x91~\xf1E=IOR\xbf9\xab\xba\x9a\xbar\xcf\
5\x0f\x91^\xc3\xf8$\xa7N\x07%\x98\x9c\xfcu^\
\xf5i\xbb<*\x92\xb4\xda\x05qhXZ\xc5\xb2|\
\xad\xe4/\xdf`\x874\xce\xf5\x03\xe0C\xff\xb7 \x1f\
\xfb\x8d%\xa1~\xbf\xbe\xe2c\xaf:+\x0fv\x04\x9b\
zN\xea\x0av\xfc\xfc\xa4tf\xa6\xd6Nbd\xa0\
\x91\x11E\x8e\x10\x11\x83\x82J\xa1\x030\x88\x04\xc6\xc6\
N\x07B$\xec\xa8\xe1\x9c\xc4\xd8\xfa}8\xd5\xd1\x9d\
\xda\x0bT\xceU[\xb3\x87\x9ao\x89Y\x97>\xd9\x0c\
\xc9\xb02\xe0\x8d\x972'`\x06\xae\x02hz\xfd\xbf\
1e1U\x99\xa8Z\xe4\xaa\x90\x11o\x99\xed\xda\xb5\
|\x10\xd5.\xa2\xaa5\xb06D\xde\x0d\x8a-D\xe3\
\xc7.M\xc6\x8d\x94Y\x9eiS\xadx\x85\xb3\x9a)\
\x84\xd9\xcf\xe4\x896\x85\x09/fE\x22R\xd92\x10\
\xeeF\xcc\x9970\x06\x08\x08\x88-\xb0\xb9dop\
1\xcf\x1df$\xbd~\xbb\x0eX\xc9\x08\x0e\x0f\xf7)\
P\xd0\x80!D\x1cN\x99\xf0*5q\x19C6\x9e\
?\x5c\xa3\xa0\x1dT\x81\xc6o. \x88{\x9a\xe9W\
\xef\x02\xf6i\x91\xa6\x05\xe2\xf9L\xcf*\x94J\x86\x0f\
,\x8b\xd9\xa1\x87\xa4\x07\x10\x80HT~\xae\x22\x96\xaa\
E\xccw\x16!JBw]My\xc3\xee\x1a\xb45\
U\
"

qt_resource_name = b"\
\x00\x06\
\x07\xae\xc3\xc3\
\x00t\
\x00h\x00e\x00m\x00e\x00s\
\x00\x06\
\x06\x98\xbd\x05\
\x00b\
\x00r\x00e\x00e\x00z\x00e\
\x00\x0b\
\x00\xd0\xbf+\
\x00b\
\x00r\x00e\x00e\x00z\x00e\x00-\x00d\x00a\x00r\x00k\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00$\x00\x04\x00\x00\x00\x01\x00\x00\x02J\
\x00\x00\x01\x8b\x0an\xba\x97\
\x00\x00\x00\x12\x00\x04\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x8b\x0an\xba\x97\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
